==> ircnotifier-0.0.1.zip: ircnotifier-0.0.1/setup.py <==
#!/usr/bin/env python

import os
from glob import glob
from distutils.util import convert_path

from setuptools import setup


def find_packages(where=".", exclude=()):
    """Borrowed directly from setuptools"""

    out = []
    stack = [(convert_path(where), "")]
    while stack:
        where, prefix = stack.pop(0)
        for name in os.listdir(where):
            fn = os.path.join(where, name)
            if ("." not in name and os.path.isdir(fn) and
                    os.path.isfile(os.path.join(fn, "__init__.py"))):
                out.append(prefix + name)
                stack.append((fn, prefix + name + "."))

    from fnmatch import fnmatchcase
    for pat in list(exclude) + ["ez_setup"]:
        out = [item for item in out if not fnmatchcase(item, pat)]

    return out

path = os.path.abspath(os.path.dirname(__file__))
try:
    README = open(os.path.join(path, "README.rst")).read()
    RELEASE = open(os.path.join(path, "RELEASE.rst")).read()
except IOError:
    README = RELEASE = ""

setup(
    name="ircnotifier",
    version='0.0.1',
    description="Python IRC Notifier Daemon",
    long_description="%s\n\n%s" % (README, RELEASE),
    author="James Mills",
    author_email="James Mills, prologic at shortcircuit dot net dot au",
    url="TBA",
    download_url="TBA",
    classifiers=[],
    license="MIT",
    keywords="Python IRC Notifier Daemon",
    platforms="POSIX",
    packages=find_packages("."),
    scripts=glob("scripts/*"),
    install_requires=[
        "circuits",
    ],
    entry_points={
        "console_scripts": [
            "ircnotifier=ircnotifier.main:main"
        ]
    },
    zip_safe=False
)

==> ircnotifier-0.0.2.zip: ircnotifier-0.0.2/setup.py <==
#!/usr/bin/env python

import os
from glob import glob
from distutils.util import convert_path

from setuptools import setup


def find_packages(where=".", exclude=()):
    """Borrowed directly from setuptools"""

    out = []
    stack = [(convert_path(where), "")]
    while stack:
        where, prefix = stack.pop(0)
        for name in os.listdir(where):
            fn = os.path.join(where, name)
            if ("." not in name and os.path.isdir(fn) and
                    os.path.isfile(os.path.join(fn, "__init__.py"))):
                out.append(prefix + name)
                stack.append((fn, prefix + name + "."))

    from fnmatch import fnmatchcase
    for pat in list(exclude) + ["ez_setup"]:
        out = [item for item in out if not fnmatchcase(item, pat)]

    return out

path = os.path.abspath(os.path.dirname(__file__))
try:
    README = open(os.path.join(path, "README.rst")).read()
    CHANGES = open(os.path.join(path, "CHANGES.rst")).read()
except IOError:
    README = CHANGES = ""

setup(
    name="ircnotifier",
    version='0.0.2',
    description="Python IRC Notifier Daemon with RESTful API using circuits",
    long_description="%s\n\n%s" % (README, CHANGES),
    author="James Mills",
    author_email="James Mills, prologic at shortcircuit dot net dot au",
    url="TBA",
    download_url="TBA",
    classifiers=[],
    license="MIT",
    keywords="Python IRC Notifier Daemon",
    platforms="POSIX",
    packages=find_packages("."),
    scripts=glob("scripts/*"),
    install_requires=[
        "circuits",
    ],
    entry_points={
        "console_scripts": [
            "ircnotifier=ircnotifier.main:main"
        ]
    },
    zip_safe=False
)
